package Form::Factory::Control::Role::MultiLine;
our $VERSION = '0.006';


use Moose::Role;

=head1 NAME

Form::Factory::Control::Role::MultiLine - multiline controls

=head1 VERSION

version 0.006

=head1 DESCRIPTION

Marks controls that have a multiline text entry.

=head1 AUTHOR

Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>

=head1 COPYRIGHT AND LICENSE

Copyright 2009 Qubling Software LLC.

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;